"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@brightside/imperative");
/**
 * Constants for workflow related APIs.
 * @export
 * @class WorkflowConstants
 */
class WorkflowConstants {
}
/**
 * URI base for workflow API.
 * @static
 * @type {string}
 * @memberof WorkflowConstants
 */
WorkflowConstants.RESOURCE = "/zosmf/workflow/rest";
/**
 * URI base for workflows API.
 * @static
 * @type {string}
 * @memberof WorkflowConstants
 */
WorkflowConstants.WORKFLOW_RESOURCE = "workflows";
/**
 * URI base for starting workflow API.
 * @static
 * @type {string}
 * @memberof WorkflowConstants
 */
WorkflowConstants.START_WORKFLOW = "operations/start";
/**
 * URI base for filtering workflow by name API.
 * @static
 * @type {string}
 * @memberof WorkflowConstants
 */
WorkflowConstants.WF_NAME = "workflowName";
/**
 * Version of the z/OSMF
 * @static
 * @type {string}
 * @memberOf WorkflowConstants
 */
WorkflowConstants.ZOSMF_VERSION = "1.0";
exports.WorkflowConstants = WorkflowConstants;
/**
 * Error message that no session was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
exports.noSession = {
    message: imperative_1.apiErrorHeader + `No session was supplied.`
};
/**
 * Error message that no z/OSMF version parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
exports.nozOSMFVersion = {
    message: imperative_1.apiErrorHeader + `No z/OSMF version parameter was supplied.`
};
/**
 * Error message that no workflow key string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
exports.noWorkflowKey = {
    message: imperative_1.apiErrorHeader + `No workflow key parameter was supplied.`
};
/**
 * Error message that no workflow definition file parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
exports.noWorkflowDefinitionFile = {
    message: imperative_1.apiErrorHeader + `No workflow definition file parameter was supplied.`
};
/**
 * Error message that no workflow name parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
exports.noWorkflowName = {
    message: imperative_1.apiErrorHeader + `No workflow name parameter was supplied.`
};
/**
 * Error message that no system name parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
exports.noSystemName = {
    message: imperative_1.apiErrorHeader + `No system name parameter was supplied.`
};
/**
 * Error message that no owner parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof WorkflowConstants
 */
exports.noOwner = {
    message: imperative_1.apiErrorHeader + `No owner parameter was supplied.`
};
exports.wrongPath = {
    message: imperative_1.apiErrorHeader + `Wrong format of USS path or DSNAME supplied.`
};
exports.wrongOwner = {
    message: imperative_1.apiErrorHeader + `Wrong format of user ID supplied.`
};
//# sourceMappingURL=WorkflowConstants.js.map